@@ -16,6 +16,23 @@ import json
 
 
 def all_file_paths_exist(file_path_dictionary):
+    """Takes a dictionary of file paths and checks if they exist.
+    
+    Takes a dictionary where each entry is a string representing a file
+    path, and iterates over all entries checking whether or not they each
+    point to a file.
+    
+    Parameters
+    ----------
+    file_path_dictionary : dict
+        a dictionary where all entries are paths to files
+        
+    Returns
+    -------
+    files_present : bool
+        a boolean saying whether or not all files in the dictionary were found
+    
+    """
     
     #Check if all files exist, and if they don't
     #return False
@@ -31,11 +48,12 @@ def all_file_paths_exist(file_path_dictionary):
 
 def generate_file_paths(lh_gii_path=None, lh_parcellation_path=None, nifti_ts_path=None,
                          nifti_parcellation_path=None, aroma_included=True):
-    
+    """
     #This function gathers paths useful for imaging analyses... either a gifti or nifti
     #or both must be specified along with accompanying parcellation paths, outputs a dictionary
     #with relevant paths, output of this function can be used with "all_file_paths_exist", then
     #with "populate_parc_dictionary", then can be saved with "save_dictionary"
+    """
     
     path_dictionary = {}
     prefix = ''
@@ -106,9 +124,9 @@ def populate_parc_dictionary(file_path_dictionary, TR):
         rh_data = imaging_utils.load_gifti_func(file_path_dictionary['rh_func_path'])
         time_series_cortex, parcel_labels_cortex, parc_median_signal_intensities = imaging_utils.demedian_parcellate_func_combine_hemis(lh_data, rh_data, file_path_dictionary['lh_parcellation_path'], file_path_dictionary['rh_parcellation_path'])
 
-        parc_ts_dictionary['labels_surface'] = parcel_labels_cortex
-        parc_ts_dictionary['time_series_surface'] = time_series_cortex
-        parc_ts_dictionary['median_ts_intensities_surface'] = parc_median_signal_intensities
+        parc_ts_dictionary['surface_labels'] = parcel_labels_cortex
+        parc_ts_dictionary['surface_time_series'] = time_series_cortex
+        parc_ts_dictionary['surface_median_ts_intensities'] = parc_median_signal_intensities
         
         
         
@@ -144,57 +162,36 @@ def populate_parc_dictionary(file_path_dictionary, TR):
                     
             parcel_labels_nifti = output_labels
             
-        parc_ts_dictionary['labels_nifti'] = parcel_labels_nifti
-        parc_ts_dictionary['time_series_nifti'] = time_series_nifti
-        parc_ts_dictionary['median_ts_intensities_nifti'] = parc_median_signal_intensities_nifti
+        parc_ts_dictionary['nifti_labels'] = parcel_labels_nifti
+        parc_ts_dictionary['nifti_time_series'] = time_series_nifti
+        parc_ts_dictionary['nifti_median_ts_intensities'] = parc_median_signal_intensities_nifti
         
         
     if (has_nifti and has_gifti):
         
-        parc_ts_dictionary['time_series'] = np.vstack((parc_ts_dictionary['time_series_surface'],parc_ts_dictionary['time_series_nifti']))
-        parc_ts_dictionary['labels'] = parc_ts_dictionary['labels_surface'] + parc_ts_dictionary['labels_nifti']
-        parc_ts_dictionary['median_ts_intensities'] = np.hstack((parc_ts_dictionary['median_ts_intensities_surface'],parc_ts_dictionary['median_ts_intensities_nifti']))
+        parc_ts_dictionary['time_series'] = np.vstack((parc_ts_dictionary['surface_time_series'],parc_ts_dictionary['nifti_time_series']))
+        parc_ts_dictionary['labels'] = parc_ts_dictionary['surface_labels'] + parc_ts_dictionary['nifti_labels']
+        parc_ts_dictionary['median_ts_intensities'] = np.hstack((parc_ts_dictionary['surface_median_ts_intensities'],parc_ts_dictionary['nifti_median_ts_intensities']))
     
     elif has_nifti:
         
-        parc_ts_dictionary['time_series'] = parc_ts_dictionary['time_series_nifti']
-        parc_ts_dictionary['labels'] = parc_ts_dictionary['labels_nifti']
-        parc_ts_dictionary['median_ts_intensities'] = parc_ts_dictionary['median_ts_intensities_nifti']
+        parc_ts_dictionary['time_series'] = parc_ts_dictionary['nifti_time_series']
+        parc_ts_dictionary['labels'] = parc_ts_dictionary['nifti_labels']
+        parc_ts_dictionary['median_ts_intensities'] = parc_ts_dictionary['nifti_median_ts_intensities']
         
     elif has_gifti:
         
-        parc_ts_dictionary['time_series'] = parc_ts_dictionary['time_series_surface']
-        parc_ts_dictionary['labels'] = parc_ts_dictionary['labels_surface']
-        parc_ts_dictionary['median_ts_intensities'] = parc_ts_dictionary['median_ts_intensities_surface']
+        parc_ts_dictionary['time_series'] = parc_ts_dictionary['surface_time_series']
+        parc_ts_dictionary['labels'] = parc_ts_dictionary['surface_labels']
+        parc_ts_dictionary['median_ts_intensities'] = parc_ts_dictionary['surface_median_ts_intensities']
         
     else:
         
         raise NameError('Error: File Path Dictionary must either have gifti or nifti specified')
     
-    
+    #Set the TR
     parc_ts_dictionary['TR'] = TR
     
-    
-    
-    ####################################################
-    #Load the melodic IC time series
-    melodic_df = pd.read_csv(file_path_dictionary['melodic_mixing_path'], sep="\t", header=None)
-    parc_ts_dictionary['melodic_mixing_matrix'] = melodic_df.values 
-
-    ####################################################
-    #Load the indices of the aroma ics
-    aroma_ics_df = pd.read_csv(file_path_dictionary['aroma_noise_ics_path'], header=None)
-    parc_ts_dictionary['aroma_noise_ic_inds'] = (aroma_ics_df.values - 1).reshape(-1,1)
-    
-
-    ####################################################
-    #Gather the ICs identified as noise/clean by AROMA
-    noise_comps = parc_ts_dictionary['aroma_noise_ic_inds']
-    all_ics = melodic_df.values 
-    mask = np.zeros(all_ics.shape[1],dtype=bool)
-    mask[noise_comps] = True
-    parc_ts_dictionary['aroma_noise_ic_timeseries'] = all_ics[:,~mask]
-    parc_ts_dictionary['aroma_clean_ic_timeseries'] = all_ics[:,mask]
 
     ####################################################
     #Get the variables from the confounds regressors file
@@ -225,7 +222,7 @@ def populate_general_info_dict(parc_ts_dictionary):
     #Calculate the number of timepoints to skip at the beginning for this person.
     #If equal to zero, we will actually call it one so that we don't run into any
     #issues during denoising with derivatives
-    general_info_dict['n_skip_vols'] = len(np.where(np.sum(np.absolute(parc_ts_dictionary['melodic_mixing_matrix']), axis=1) < 0.1)[0])
+    general_info_dict['n_skip_vols'] = len(np.where(np.absolute(parc_ts_dictionary['confounds']['a_comp_cor_00']) < 0.00001)[0])
     if general_info_dict['n_skip_vols'] == 0:
         general_info_dict['n_skip_vols'] = 1
                 
@@ -323,108 +320,25 @@ def populate_confounds_dict(file_path_dictionary):
                                          confounds_dictionary['a_comp_cor_02'], confounds_dictionary['a_comp_cor_03'],
                                          confounds_dictionary['a_comp_cor_04']))
         
+        ####################################################
+        #Load the melodic IC time series
+        melodic_df = pd.read_csv(file_path_dictionary['melodic_mixing_path'], sep="\t", header=None)        
+        
+        ####################################################
+        #Load the indices of the aroma ics
+        aroma_ics_df = pd.read_csv(file_path_dictionary['aroma_noise_ics_path'], header=None)
+        noise_comps = (aroma_ics_df.values - 1).reshape(-1,1)
+
+
+        ####################################################
+        #Gather the ICs identified as noise/clean by AROMA
+        all_ics = melodic_df.values 
+        mask = np.zeros(all_ics.shape[1],dtype=bool)
+        mask[noise_comps] = True
+        confounds_dictionary['aroma_noise_ics'] = np.transpose(all_ics[:,~mask])
+        confounds_dictionary['aroma_clean_ics'] = np.transpose(all_ics[:,mask])
+        
         return confounds_dictionary
     
     
     
-def save_dictionary(dictionary, path_for_dictionary_dir, overwrite = False):
-    
-        
-    if path_for_dictionary_dir[-5:] == '.json':
-        
-        with open(os.path.join(path_for_dictionary_dir), 'w') as temp_file:
-            json_dict = json.dumps(dictionary, indent = 4, sort_keys = True)
-            temp_file.write(json_dict)        
-
-    else:
-        
-        if os.path.exists(path_for_dictionary_dir) == True:
-        
-            if overwrite == False:
-
-                raise NameError('Error: Parc Timeseries Dictionary Directory Already Exists at this path')
-
-        else:
-        
-            os.makedirs(path_for_dictionary_dir)
-        
-        
-        
-        for temp_key in dictionary.keys():
-
-
-            if type(dictionary[temp_key]) == dict:
-
-                to_overwrite = overwrite
-                save_dictionary(dictionary[temp_key], os.path.join(path_for_dictionary_dir, temp_key), overwrite = to_overwrite)
-
-            else:
-
-
-                if path_for_dictionary_dir[-3:] == 'txt':
-
-                    with open(os.path.join(path_for_dictionary_dir, temp_key), 'w') as temp_file:
-                        temp_file.write(str(dictionary[temp_key]))
-
-                else:
-
-                    np.save(os.path.join(path_for_dictionary_dir, temp_key), dictionary[temp_key])
-                 
-            
-    return
-                
-                
-    
-    
-    
-def load_dictionary(dictionary_dir_path):
-    
-    dictionary = {}
-    
-    os.chdir(dictionary_dir_path)
-    directory_contents = os.listdir()
-    directory_final_name = dictionary_dir_path.split('/')[-1]
-    for temp_file in directory_contents:
-        
-        if os.path.isdir(temp_file):
-            
-            dictionary[temp_file] = load_dictionary(os.path.join(dictionary_dir_path, temp_file))
-            os.chdir(dictionary_dir_path)
-            
-        else:
-            
-            if temp_file[-5:] == '.json':
-                                
-                with open(temp_file, 'r') as temp_json:
-                    json_contents = temp_json.read()
-                    dictionary[temp_file] = json.loads(json_contents)
-                    
-            else:
-            
-                if dictionary_dir_path[-3:] == 'txt':
-
-                    with open(temp_file,'r') as temp_reading:
-                        file_contents = temp_reading.read()
-
-                        try:
-                            dictionary[temp_file.split('.')[0]] = float(file_contents)
-                        except:
-
-                            if file_contents[0] == '[' and file_contents[-1] == ']':
-                                split_contents = file_contents[1:-1].split(',')
-                                dictionary[temp_file.split('.')[0]] = []
-                                for temp_item in split_contents:
-                                    split_limited_1 = temp_item.replace(' ','')
-                                    split_limited_2 = split_limited_1.replace("'","")
-                                    dictionary[temp_file.split('.')[0]].append(split_limited_2)
-
-                            else:
-                                dictionary[temp_file.split('.')[0]] = file_contents                
-
-                else:
-
-                    dictionary[temp_file.split('.')[0]] = np.load(temp_file)
-                
-                
-                
-    return dictionary
